//
// tischar.h - TIS-620 char set definitions
// Created: 19 Jan 1999
// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
//

#ifndef __TISCHAR_H
#define __TISCHAR_H

typedef unsigned char tischar;

const tischar BAD_TISCHAR = 0x80;

#endif  // __TISCHAR_H

